@@ -54,9 +54,10 @@ sub _stringify
    my ($self) = @_;
    my $under_tie = tied @{ $self };
    my @values = @{ $under_tie->{'data'} };
-   $under_tie->{'parent'}{'opts'}{'csv_parser'}->combine(@values)
-      || croak $under_tie->{'parent'}{'opts'}{'csv_parser'}->error_input();
-   return $under_tie->{'parent'}{'opts'}{'csv_parser'}->string();
+   my $opts      = *{ $under_tie->{'parent'} }->{opts};
+   $opts->{'csv_parser'}->combine(@values)
+      || croak $opts->{'csv_parser'}->error_input();
+   return $opts->{'csv_parser'}->string();
    }
 
 1;
